@@ -3,8 +3,9 @@ BEGIN {
   $App::DuckPAN::Cmd::Rm::AUTHORITY = 'cpan:DDG';
 }
 {
-  $App::DuckPAN::Cmd::Rm::VERSION = '0.101';
+  $App::DuckPAN::Cmd::Rm::VERSION = '0.102';
 }
+# ABSTRACT: Remove an ENV variable
 
 use Moo;
 extends 'App::DuckPAN::CmdBase::Env';
@@ -29,11 +30,11 @@ __END__
 
 =head1 NAME
 
-App::DuckPAN::Cmd::Rm
+App::DuckPAN::Cmd::Rm - Remove an ENV variable
 
 =head1 VERSION
 
-version 0.101
+version 0.102
 
 =head1 AUTHOR
 
